//
// Created by sebastien lato on 2024-02-09.
//
#include "menu.h"
#include "number_utils.h"
#include "io_utils.h"
#include <iostream>
#include <cstdio>

/**
 * @brief Exécute le menu principal de l'application et traite les choix de l'utilisateur.
 *
 * @details Cette fonction affiche un menu interactif avec différentes options liées au traitement
 *          de nombres entiers signés sur 16 bits, au calcul de l'epsilon pour les types float et double,
 *          à la sommation de séries, à l'exécution de sommations ascendante et descendante,
 *          et au calcul de la trajectoire d'une balle. L'utilisateur peut sélectionner une option
 *          pour exécuter une tâche spécifique et a la possibilité de quitter le programme en choisissant
 *          l'option appropriée. La fonction gère également les entrées non valides et invite
 *          l'utilisateur à réessayer.
 *
 * INPUT: aucun
 * OUTPUT: aucun (les interactions se font via la console/terminal)
 */
void run_menu() {
    int choix;
    bool continuer = true;
    char rep;

    while (continuer) {
        std::cout << "\t|--------------------|\n";
        std::cout << "\t| Menu Principal TP1 |\n";
        std::cout << "\t|--------------------|\n";
        std::cout << "1. Vérifier la somme de deux nombres entiers signés sur 16 bits\n";
        std::cout << "2. Afficher la valeur du epsilon ainsi que le nombre de chiffres binaires significatifs\n";
        std::cout << "3. Sommation successive de 1/n (multiple de 100)\n";
        std::cout << "4. Exécuter sommation ascendante et descendante \n";
        std::cout << "5. Calculer trajectoire de la balle\n";
        std::cout << "6. Quitter\n";
        std::cout << "Entrez votre choix: ";
        std::cin >> choix;
        clearStdinBuffer();

        switch (choix) {
            case 1:
                do {
                    additionSINT();
                    std::printf("\nVoulez-vous verifier la somme de 2 shorts (y/n)? ");
                    while ((rep = std::getchar()) == '\n');
                    clearStdinBuffer();
                } while (rep == 'y' || rep == 'Y');
                break;
            case 2:
                epsilonf();
                epsilond();
                break;
            case 3:
                do {
                    int n = demanderMultipleDeCent();
                    sommef(n);
                    sommed(n);
                    std::printf("\nVoulez-vous essayer avec un autre multiple de cent (y/n)? ");
                    while ((rep = std::getchar()) == '\n');
                    clearStdinBuffer();
                } while (rep == 'y' || rep == 'Y');
                break;
            case 4:
                run_sommations();
                break;
            case 5:
                run_trajectoire();
                break;
            case 6:
                continuer = false;
                break;
            default:
                std::cout << "Choix non valide, veuillez réessayer.\n";
                break;
        }
    }
}
