//
// Created by sebastien lato on 2024-02-08.
//
#include <iostream>
#include <iomanip>
#include <cmath>
#include "number_utils.h"

/**
 * @brief Exécute des séries de sommations en simple et double précision.
 *
 * @details Cette fonction effectue des séries de sommations ascendantes et descendantes
 *          pour des exposants allant de 1 à 3, à la fois en simple (float) et en double précision (double).
 *          Chaque série de sommations est effectuée pour 10^exposant éléments. La précision de l'affichage
 *          est fixée à 30 chiffres après la virgule pour toutes les sorties flottantes. Cela permet d'observer
 *          les différences de précision et les effets d'erreur d'arrondi dans les calculs en simple et double précision.
 *          La fonction affiche les résultats des sommations ascendantes et descendantes pour chaque type de précision
 *          et chaque valeur de l'exposant.
 *
 * INPUT: aucun
 * OUTPUT: aucun (imprime les résultats des sommations sur la sortie standard)
 */
void run_sommations() {
    std::cout << std::fixed << std::setprecision(30); // Fixe la précision pour toute la sortie flottante

    // Sommation ascendante en simple précision pour les exposants 1, 2, et 3
    for (int exponent = 1; exponent <= 3; ++exponent) {
        int n = static_cast<int>(std::pow(10, exponent));
        std::cout << "Somme asc (float) :";
        sommeascf(n);
        std::cout << " " << exponent << ".000000\n";
    }
    std::cout << "\n";

    // Sommation ascendante en double précision pour les exposants 1, 2, et 3
    for (int exponent = 1; exponent <= 3; ++exponent) {
        int n = static_cast<int>(std::pow(10, exponent));
        std::cout << "Somme asc (double) :";
        sommeascd(n);
        std::cout << " " << exponent << ".000000\n";
    }
    std::cout << "\n";

    // Sommation descendante en simple précision pour les exposants 1, 2, et 3
    for (int exponent = 1; exponent <= 3; ++exponent) {
        int n = static_cast<int>(std::pow(10, exponent));
        std::cout << "Somme desc (float):";
        sommedescf(n);
        std::cout << " " << exponent << ".000000\n";
    }
    std::cout << "\n";

    // Sommation descendante en double précision pour les exposants 1, 2, et 3
    for (int exponent = 1; exponent <= 3; ++exponent) {
        int n = static_cast<int>(std::pow(10, exponent));
        std::cout << "Somme desc (double) :";
        sommedescd(n);
        std::cout << " " << exponent << ".000000\n";
    }
    std::cout << "\n";
}

