//
// Created by sebastien lato on 2024-02-09.
//
#include "io_utils.h"
#include "trajectoire.h"
#include <iostream>
#include <iomanip>

/**
 * @brief Calcule et affiche la distance parcourue par un projectile.
 *
 * @details Cette fonction utilise la méthode de la bissection pour trouver la distance horizontale
 *          parcourue par un projectile lancé avec une vitesse initiale et un angle donnés, depuis une hauteur initiale.
 *          Elle définit les paramètres du tir, tels que l'angle de lancement, la vitesse initiale, la hauteur initiale,
 *          et les bornes pour la recherche de la racine. La fonction utilise ces paramètres pour calculer la distance
 *          en utilisant une fonction (non montrée ici) nommée 'rtbis', qui implémente la méthode de la bissection.
 *          La précision des calculs et de l'affichage est contrôlée par des constantes définies ailleurs dans le code.
 *          Le résultat, la distance horizontale parcourue par le projectile, est ensuite affiché avec une précision élevée.
 *
 * INPUT: aucun
 * OUTPUT: aucun (imprime la distance parcourue sur la sortie standard)
 */
void run_trajectoire() {
    // Paramètres pour le tir d'un projectile
    double theta0 = 30.0; // Angle de lancement en degrés
    double v0 = 50.0;     // Vitesse initiale en m/s
    double y0 = 2.0;      // Hauteur initiale en mètres
    double x1 = 1.0;      // Borne inférieure pour la recherche de la racine en mètres
    double x2 = 300.0;    // Borne supérieure pour la recherche de la racine en mètres

    // Affichage avec précision fixée
    std::cout << std::fixed << std::setprecision(20);

    // Calcul de la distance en x parcourue par la balle (la racine de la fonction F)
    double distance = rtbis(x1, x2, theta0, v0, y0, PRECISIONX, PRECISIONZERO);

    // Affichage de la distance
    std::cout << "Valeur de la racine (bissection) = " << distance << " m." << std::endl;
}
