//
// Created by sebastien lato on 2024-02-08.
//
#include <iostream>
#include "number_utils.h"

/**
 * @brief Calcule et affiche la sommation descendante de la série harmonique jusqu'à n en simple précision.
 *
 * @details Cette fonction réalise une sommation descendante (de n à 1) de la série harmonique,
 *          où chaque terme est de la forme 1/i, avec i décroissant de n jusqu'à 1. La sommation est effectuée
 *          en simple précision (float) pour illustrer l'impact de la précision sur le résultat final
 *          de la sommation. Comparée à la sommation en double précision, cette méthode peut montrer
 *          une différence notable dans le résultat final pour des valeurs élevées de n, en raison
 *          des erreurs d'arrondi accumulées durant la sommation. La sommation descendante peut parfois
 *          atténuer les erreurs d'arrondi par rapport à une sommation ascendante en commençant par les termes
 *          les plus petits, réduisant ainsi potentiellement leur impact cumulatif sur le total.
 *
 * INPUT: n (int) - Le nombre de termes de la série harmonique à sommer.
 * OUTPUT: Aucun (imprime la somme calculée sur la sortie standard).
 */
void sommedescf(int n) {
    float sum = 0.0f;
    for (int i = n; i >= 1; --i) {
        sum += 1.0f / static_cast<float>(i);
    }
    std::cout << sum;
}