//
// Created by sebastien lato on 2024-02-09.
//
#include "trajectoire.h"
#include <cmath>
#include <cstdio>

// Fonction qui calcule la valeur de la fonction parabolique, qui calcule la position y (hauteur)
// d'une balle sur sa trajectoire en x, en fonction de l'angle initial theta0, de la vitesse initiale v0
// et de la hauteur initiale y0
double F(double x, double theta0, double v0, double y0) {
    // La formule pour la position y en fonction de la position x pour une trajectoire parabolique
    return tan(theta0 * PI / 180.0) * x - (G / (2.0 * v0 * v0 * cos(theta0 * PI / 180.0) * cos(theta0 * PI / 180.0))) * x * x + y0;
}

// Fonction de bissection rtbis pour trouver la racine de la fonction F, c'est-à-dire la valeur de x pour laquelle F(x) = 0
double rtbis(double x1, double x2, double theta0, double v0, double y0, double xacc, double zeroacc) {
    int j;
    double dx, f, fmid, xmid, rtb;

    f = F(x1, theta0, v0, y0);
    fmid = F(x2, theta0, v0, y0);
    if (f * fmid >= 0.0) {
        printf("Racine absente de cet intervalle dans RTBIS\n");
        return 0; // ou une autre gestion d'erreur
    }
    rtb = f < 0.0 ? (dx = x2 - x1, x1) : (dx = x1 - x2, x2);
    for (j = 1; j <= MAXIT; j++) {
        fmid = F(xmid = rtb + (dx *= 0.5), theta0, v0, y0);
        if (fmid <= 0.0) rtb = xmid;
        if (fabs(dx) < xacc || fabs(fmid) < zeroacc) {
            printf("\nNombre d'iterations: %d dx: %17.15lf f(rtb): %17.15lf\n", j, dx, fmid);
            return rtb; // La racine a été trouvée
        }
    }
    printf("Trop de bissections dans RTBIS\n");
    return rtb; // Retourne la dernière estimation de la racine
}
